@@ -131,6 +131,7 @@ def cli(ctx: click.Context, **kwargs):
 )
 @click.option(
     "--incremental-fresh",
+    is_flag=True,
     default=False,
     help="In incremental mode, cleanup folder contents before running.",
 )
@@ -171,6 +172,20 @@ def cli(ctx: click.Context, **kwargs):
     # mutually_exclusive_with=["xedaproject"],
     help="Path to Xeda design file containing the description of a single design.",
 )
+@click.option(
+    "--design-overrides",
+    metavar="KEY=VALUE...",
+    type=tuple,
+    cls=OptionEatAll,
+    help="""Override design attributes.""",
+)
+@click.option(
+    "--design-allow-extra/--no-design-allow-extra",
+    type=bool,
+    is_flag=True,
+    default=False,
+    help="""Allow extra properties (fields) in design description.""",
+)
 @click.option(
     "--flow-settings",
     "--settings",
@@ -213,6 +228,8 @@ def run(
     xedaproject: Optional[str] = None,
     design_name: Optional[str] = None,
     design_file: Optional[str] = None,
+    design_overrides: Iterable[str] = tuple(),
+    design_allow_extra: bool = False,
     log_level: Optional[int] = None,
     detailed_logs: bool = False,
     post_cleanup: bool = False,
@@ -229,9 +246,7 @@ def run(
         log_level = (
             logging.WARNING if options.quiet else logging.DEBUG if options.debug else logging.INFO
         )
-    setup_logger(log_level, detailed_logs, xeda_run_dir / "Logs" if detailed_logs else None)
-    if isinstance(flow_settings, str):
-        flow_settings = flow_settings.split(",")
+    setup_logger(log_level, detailed_logs, (xeda_run_dir / "Logs") if detailed_logs else None)
     if flow_settings is not None:
         flow_settings = list(flow_settings)
 
@@ -242,8 +257,13 @@ def run(
         design_file=design_file,
         flow_settings=flow_settings,
         select_design_in_project=select_design_in_project,
+        design_overrides=design_overrides,
+        design_allow_extra=design_allow_extra,
+        design_remove_extra=["lwc"],
     )
     if not design or not flow_class:
+        if options.debug:
+            raise ValueError(f"design={design} flow_ckass={flow_class}")
         sys.exit(1)
     try:
         launcher = DefaultRunner(
@@ -263,9 +283,13 @@ def run(
             flow,
             " ".join(str(a) for a in e.args),
         )
+        if options.debug:
+            raise e
         sys.exit(1)
     except NonZeroExitCode as e:
         log.critical("Flow %s failed: NonZeroExitCode %s", flow, " ".join(str(a) for a in e.args))
+        if options.debug:
+            raise e
         sys.exit(1)
     except ExecutableNotFound as e:
         log.critical(
@@ -279,12 +303,12 @@ def run(
     except FlowSettingsError as e:
         log.critical("%s", e)
         if options.debug:
-            raise e from None
+            raise e
         sys.exit(1)
     except FlowException as e:  # any flow exception
         log.critical("%s", e)
         if options.debug:
-            raise e from None
+            raise e
         sys.exit(1)
 
 
@@ -399,6 +423,13 @@ def list_settings(ctx: click.Context, flow):
     ),
     help="Path to Xeda design file containing the description of a single design.",
 )
+@click.option(
+    "--design-allow-extra/--no-design-allow-extra",
+    type=bool,
+    is_flag=True,
+    default=True,  # by default allow for dse
+    help="""Allow extra properties (fields) in design description.""",
+)
 @click.option("--detailed-logs/--no-detailed-logs", show_envvar=True, default=True)
 @click.option("--log-level", show_envvar=True, type=int, default=None)
 @click.option(
@@ -454,6 +485,7 @@ def dse(
     xedaproject: Optional[str] = None,
     design_name: Optional[str] = None,
     design_file: Optional[str] = None,
+    design_allow_extra: bool = True,
     log_level: Optional[int] = None,
     detailed_logs: bool = True,
 ):
@@ -477,6 +509,8 @@ def dse(
         design_file=design_file,
         flow_settings=list(flow_settings),
         select_design_in_project=select_design_in_project,
+        design_remove_extra=["lwc"],
+        design_allow_extra=design_allow_extra,
     )
     opt_settings = settings_to_dict(optimizer_settings, expand_dict_keys=True)
     dse_settings_dict = settings_to_dict(dse_settings, expand_dict_keys=True)
