@@ -33,7 +33,7 @@ from rich.table import Table
 from rich.text import Text
 
 from ..console import console
-from ..dataclass import XedaBaseModel, asdict, define
+from ..dataclass import XedaBaseModel, asdict
 from ..design import Design, DesignValidationError, FileResource
 from ..flow import Flow, FlowDependencyFailure, registered_flows
 from ..tool import NonZeroExitCode
@@ -341,7 +341,10 @@ class FlowLauncher:
                 ):
                     previous_results = Box(prev_results)
                 else:
-                    log.warning("%s does not contain the expected settings", prev_settings)
+                    log.warning(
+                        "%s does not contain the expected flow and/or design hash.",
+                        str(settings_json.absolute()),
+                    )
             else:
                 log.warning(
                     "Could not find valid results/settings from a previous run in %s",
@@ -455,7 +458,7 @@ class FlowLauncher:
                 except Exception as e:  # pylint: disable=broad-except
                     log.critical("parse_reports threw an exception: %s", e)
                     if success:  # if so far so good this is a bug!
-                        raise e from None
+                        raise e
                 if not success:
                     log.warning("Failure was reported in the parsed results.")
                 flow.results.success = success
@@ -559,8 +562,7 @@ def add_file_logger(logdir: Path, timestamp: Union[None, str, datetime] = None):
     log.root.addHandler(fileHandler)
 
 
-@define
-class XedaOptions:
+class XedaOptions(XedaBaseModel):
     verbose: bool = False
     quiet: bool = False
     debug: bool = False
@@ -612,16 +614,30 @@ def prepare(
     design_file: Union[None, str, os.PathLike] = None,
     flow_settings: Union[List[str], None] = None,
     select_design_in_project=None,
+    design_overrides: Union[None, Iterable[str], Dict[str, Any]] = None,
+    design_allow_extra: bool = False,
+    design_remove_extra: List[str] = [],
 ) -> Tuple[Optional[Design], Optional[Type[Flow]], Dict[str, Any]]:
     # get default flow configs from xedaproject even if a design-file is specified
     xeda_project = None
     flows_settings: Dict[str, Any] = {}
     design: Optional[Design] = None
+    if not design_overrides:
+        design_overrides = {}
+    if not isinstance(design_overrides, dict):
+        design_overrides = list(design_overrides)
+        design_overrides = settings_to_dict(design_overrides)
     if not xedaproject:
         xedaproject = "xedaproject.toml"
     if Path(xedaproject).exists():
         try:
-            xeda_project = XedaProject.from_file(xedaproject, skip_designs=design_file is not None)
+            xeda_project = XedaProject.from_file(
+                xedaproject,
+                skip_designs=design_file is not None,
+                design_overrides=design_overrides,
+                design_allow_extra=design_allow_extra,
+                design_remove_extra=design_remove_extra,
+            )
         except DesignValidationError as e:
             log.critical("%s", e)
             return None, None, flows_settings
@@ -633,12 +649,17 @@ def prepare(
         flows_settings = xeda_project.flows
     if design_file:
         try:
-            design = Design.from_toml(design_file)
+            design = Design.from_toml(
+                design_file,
+                overrides=design_overrides,
+                allow_extra=design_allow_extra,
+                remove_extra=design_remove_extra,
+            )
             dd = asdict(design)
             flows_settings = {
                 **flows_settings,
                 **dd.get("flows", {}),
-                **dd.get("flow", {}),
+                **design.flow,
             }
         except DesignValidationError as e:
             log.critical("%s", e)
